From bd44da9c52177cf24c8cbf51159bb180f2f5a355 Mon Sep 17 00:00:00 2001
From: Thomas Munro <thomas.munro@gmail.com>
Date: Fri, 14 Apr 2023 09:26:28 +1200
Subject: [PATCH] Trust signalfd on illumos, again.

Commit 3ab4fc5d avoided choosing signalfd by default on illumos, because it
triggered kernel panics.  That was fixed, so we can remove a kludge from our
code.  Users/packagers can still override the default choice at compile time if
desired, and we'll leave the back-branches unchanged so they keep choosing
self-pipe by default, but we'll default to signalfd (ie remove the special
cases and treat it just like Linux) from 16.  Fixed kernels should be
everywhere by the time 16 ships.

The illumos issues was: https://www.illumos.org/issues/14892

diff --git a/src/backend/storage/ipc/latch.c b/src/backend/storage/ipc/latch.c
index f4123e7de7..13a8c6ec28 100644
--- a/src/backend/storage/ipc/latch.c
+++ b/src/backend/storage/ipc/latch.c
@@ -86,14 +86,12 @@
 
 /*
  * By default, we use a self-pipe with poll() and a signalfd with epoll(), if
- * available.  We avoid signalfd on illumos for now based on problem reports.
- * For testing the choice can also be manually specified.
+ * available.  For testing the choice can also be manually specified.
  */
 #if defined(WAIT_USE_POLL) || defined(WAIT_USE_EPOLL)
 #if defined(WAIT_USE_SELF_PIPE) || defined(WAIT_USE_SIGNALFD)
 /* don't overwrite manual choice */
-#elif defined(WAIT_USE_EPOLL) && defined(HAVE_SYS_SIGNALFD_H) && \
-	!defined(__illumos__)
+#elif defined(WAIT_USE_EPOLL) && defined(HAVE_SYS_SIGNALFD_H)
 #define WAIT_USE_SIGNALFD
 #else
 #define WAIT_USE_SELF_PIPE
-- 
2.39.2 (Apple Git-143)

